@@ -156,18 +156,18 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_autoscaling
-import aws_cdk.aws_ec2
-import aws_cdk.aws_ecs
-import aws_cdk.aws_efs
-import aws_cdk.aws_logs
-import aws_cdk.aws_sns
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_autoscaling as _aws_cdk_aws_autoscaling_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_ceddda9d
+import aws_cdk.aws_efs as _aws_cdk_aws_efs_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class LowCostECS(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="low-cost-ecs.LowCostECS",
 ):
@@ -177,7 +177,7 @@ class LowCostECS(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         email: builtins.str,
@@ -188,12 +188,12 @@ class LowCostECS(
         container_insights: typing.Optional[builtins.bool] = None,
         host_instance_spot_price: typing.Optional[builtins.str] = None,
         host_instance_type: typing.Optional[builtins.str] = None,
-        log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
+        log_group: typing.Optional[_aws_cdk_aws_logs_ceddda9d.ILogGroup] = None,
         record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-        server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+        server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     ) -> None:
         '''
         :param scope: -
@@ -216,27 +216,7 @@ class LowCostECS(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                email: builtins.str,
-                hosted_zone_domain: builtins.str,
-                aws_cli_docker_tag: typing.Optional[builtins.str] = None,
-                certbot_docker_tag: typing.Optional[builtins.str] = None,
-                certbot_schedule_interval: typing.Optional[jsii.Number] = None,
-                container_insights: typing.Optional[builtins.bool] = None,
-                host_instance_spot_price: typing.Optional[builtins.str] = None,
-                host_instance_type: typing.Optional[builtins.str] = None,
-                log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
-                record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-                server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
-                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c0356d0ba92a1b88dbec557c9706dec10d39b53bd74af24510f519ceae784aea)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LowCostECSProps(
@@ -260,58 +240,60 @@ class LowCostECS(
 
     @builtins.property
     @jsii.member(jsii_name="certFileSystem")
-    def cert_file_system(self) -> aws_cdk.aws_efs.FileSystem:
+    def cert_file_system(self) -> _aws_cdk_aws_efs_ceddda9d.FileSystem:
         '''(experimental) EFS file system that the SSL/TLS certificates are installed.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_efs.FileSystem, jsii.get(self, "certFileSystem"))
+        return typing.cast(_aws_cdk_aws_efs_ceddda9d.FileSystem, jsii.get(self, "certFileSystem"))
 
     @builtins.property
     @jsii.member(jsii_name="cluster")
-    def cluster(self) -> aws_cdk.aws_ecs.Cluster:
+    def cluster(self) -> _aws_cdk_aws_ecs_ceddda9d.Cluster:
         '''(experimental) ECS cluster created in configured VPC.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ecs.Cluster, jsii.get(self, "cluster"))
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.Cluster, jsii.get(self, "cluster"))
 
     @builtins.property
     @jsii.member(jsii_name="hostAutoScalingGroup")
-    def host_auto_scaling_group(self) -> aws_cdk.aws_autoscaling.AutoScalingGroup:
+    def host_auto_scaling_group(
+        self,
+    ) -> _aws_cdk_aws_autoscaling_ceddda9d.AutoScalingGroup:
         '''(experimental) ECS on EC2 service host instance autoscaling group.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_autoscaling.AutoScalingGroup, jsii.get(self, "hostAutoScalingGroup"))
+        return typing.cast(_aws_cdk_aws_autoscaling_ceddda9d.AutoScalingGroup, jsii.get(self, "hostAutoScalingGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="serverTaskDefinition")
-    def server_task_definition(self) -> aws_cdk.aws_ecs.Ec2TaskDefinition:
+    def server_task_definition(self) -> _aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinition:
         '''(experimental) Server task definition generated from LowCostECSTaskDefinitionOptions.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ecs.Ec2TaskDefinition, jsii.get(self, "serverTaskDefinition"))
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinition, jsii.get(self, "serverTaskDefinition"))
 
     @builtins.property
     @jsii.member(jsii_name="service")
-    def service(self) -> aws_cdk.aws_ecs.Ec2Service:
+    def service(self) -> _aws_cdk_aws_ecs_ceddda9d.Ec2Service:
         '''(experimental) ECS service of the server with desiredCount: 1, minHealthyPercent: 0, maxHealthyPercent: 100.
 
         :stability: experimental
         :link: https://github.com/rajyan/low-cost-ecs#limitations
         '''
-        return typing.cast(aws_cdk.aws_ecs.Ec2Service, jsii.get(self, "service"))
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.Ec2Service, jsii.get(self, "service"))
 
     @builtins.property
     @jsii.member(jsii_name="topic")
-    def topic(self) -> aws_cdk.aws_sns.Topic:
+    def topic(self) -> _aws_cdk_aws_sns_ceddda9d.Topic:
         '''(experimental) SNS topic used to notify certbot renewal failure.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "topic"))
+        return typing.cast(_aws_cdk_aws_sns_ceddda9d.Topic, jsii.get(self, "topic"))
 
 
 @jsii.data_type(
@@ -346,12 +328,12 @@ class LowCostECSProps:
         container_insights: typing.Optional[builtins.bool] = None,
         host_instance_spot_price: typing.Optional[builtins.str] = None,
         host_instance_type: typing.Optional[builtins.str] = None,
-        log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
+        log_group: typing.Optional[_aws_cdk_aws_logs_ceddda9d.ILogGroup] = None,
         record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-        server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+        server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     ) -> None:
         '''
         :param email: (experimental) Email for expiration emails to register to your let's encrypt account.
@@ -374,25 +356,7 @@ class LowCostECSProps:
         if isinstance(server_task_definition, dict):
             server_task_definition = LowCostECSTaskDefinitionOptions(**server_task_definition)
         if __debug__:
-            def stub(
-                *,
-                email: builtins.str,
-                hosted_zone_domain: builtins.str,
-                aws_cli_docker_tag: typing.Optional[builtins.str] = None,
-                certbot_docker_tag: typing.Optional[builtins.str] = None,
-                certbot_schedule_interval: typing.Optional[jsii.Number] = None,
-                container_insights: typing.Optional[builtins.bool] = None,
-                host_instance_spot_price: typing.Optional[builtins.str] = None,
-                host_instance_type: typing.Optional[builtins.str] = None,
-                log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
-                record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-                server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
-                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8a4e374b4001b2d1a00530b347f4892645cdf6f0c73a3b5609e0b85fb859de79)
             check_type(argname="argument email", value=email, expected_type=type_hints["email"])
             check_type(argname="argument hosted_zone_domain", value=hosted_zone_domain, expected_type=type_hints["hosted_zone_domain"])
             check_type(argname="argument aws_cli_docker_tag", value=aws_cli_docker_tag, expected_type=type_hints["aws_cli_docker_tag"])
@@ -407,7 +371,7 @@ class LowCostECSProps:
             check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
             check_type(argname="argument server_task_definition", value=server_task_definition, expected_type=type_hints["server_task_definition"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "email": email,
             "hosted_zone_domain": hosted_zone_domain,
         }
@@ -530,7 +494,7 @@ class LowCostECSProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def log_group(self) -> typing.Optional[aws_cdk.aws_logs.ILogGroup]:
+    def log_group(self) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.ILogGroup]:
         '''(experimental) Log group of the certbot task and the aws-cli task.
 
         :default: - Creates default cdk log group
@@ -538,7 +502,7 @@ class LowCostECSProps:
         :stability: experimental
         '''
         result = self._values.get("log_group")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.ILogGroup], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.ILogGroup], result)
 
     @builtins.property
     def record_domain_names(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -552,7 +516,7 @@ class LowCostECSProps:
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy]:
         '''(experimental) Removal policy for the file system and log group (if using default).
 
         :default: - RemovalPolicy.DESTROY
@@ -560,12 +524,12 @@ class LowCostECSProps:
         :stability: experimental
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy], result)
 
     @builtins.property
     def security_groups(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]]:
         '''(experimental) Security group of the ECS host instance.
 
         :default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
@@ -573,7 +537,7 @@ class LowCostECSProps:
         :stability: experimental
         '''
         result = self._values.get("security_groups")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]], result)
 
     @builtins.property
     def server_task_definition(
@@ -590,7 +554,7 @@ class LowCostECSProps:
         return typing.cast(typing.Optional["LowCostECSTaskDefinitionOptions"], result)
 
     @builtins.property
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''(experimental) VPC of the ECS cluster and EFS file system.
 
         :default: - Creates vpc with only public subnets and no NAT gateways.
@@ -598,7 +562,7 @@ class LowCostECSProps:
         :stability: experimental
         '''
         result = self._values.get("vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -625,9 +589,9 @@ class LowCostECSTaskDefinitionOptions:
     def __init__(
         self,
         *,
-        containers: typing.Sequence[typing.Union[aws_cdk.aws_ecs.ContainerDefinitionOptions, typing.Dict[str, typing.Any]]],
-        task_definition: typing.Optional[typing.Union[aws_cdk.aws_ecs.Ec2TaskDefinitionProps, typing.Dict[str, typing.Any]]] = None,
-        volumes: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.Volume, typing.Dict[str, typing.Any]]]] = None,
+        containers: typing.Sequence[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinitionOptions, typing.Dict[builtins.str, typing.Any]]],
+        task_definition: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinitionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        volumes: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_ecs_ceddda9d.Volume, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param containers: 
@@ -637,20 +601,13 @@ class LowCostECSTaskDefinitionOptions:
         :stability: experimental
         '''
         if isinstance(task_definition, dict):
-            task_definition = aws_cdk.aws_ecs.Ec2TaskDefinitionProps(**task_definition)
+            task_definition = _aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinitionProps(**task_definition)
         if __debug__:
-            def stub(
-                *,
-                containers: typing.Sequence[typing.Union[aws_cdk.aws_ecs.ContainerDefinitionOptions, typing.Dict[str, typing.Any]]],
-                task_definition: typing.Optional[typing.Union[aws_cdk.aws_ecs.Ec2TaskDefinitionProps, typing.Dict[str, typing.Any]]] = None,
-                volumes: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.Volume, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__002ebbd53d2519dadc4020acc93b39be5a360ef0d6f0ca12153b8e9f6ca81d6e)
             check_type(argname="argument containers", value=containers, expected_type=type_hints["containers"])
             check_type(argname="argument task_definition", value=task_definition, expected_type=type_hints["task_definition"])
             check_type(argname="argument volumes", value=volumes, expected_type=type_hints["volumes"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "containers": containers,
         }
         if task_definition is not None:
@@ -659,31 +616,33 @@ class LowCostECSTaskDefinitionOptions:
             self._values["volumes"] = volumes
 
     @builtins.property
-    def containers(self) -> typing.List[aws_cdk.aws_ecs.ContainerDefinitionOptions]:
+    def containers(
+        self,
+    ) -> typing.List[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinitionOptions]:
         '''
         :stability: experimental
         '''
         result = self._values.get("containers")
         assert result is not None, "Required property 'containers' is missing"
-        return typing.cast(typing.List[aws_cdk.aws_ecs.ContainerDefinitionOptions], result)
+        return typing.cast(typing.List[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinitionOptions], result)
 
     @builtins.property
     def task_definition(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.Ec2TaskDefinitionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinitionProps]:
         '''
         :stability: experimental
         '''
         result = self._values.get("task_definition")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.Ec2TaskDefinitionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinitionProps], result)
 
     @builtins.property
-    def volumes(self) -> typing.Optional[typing.List[aws_cdk.aws_ecs.Volume]]:
+    def volumes(self) -> typing.Optional[typing.List[_aws_cdk_aws_ecs_ceddda9d.Volume]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("volumes")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ecs.Volume]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_ecs_ceddda9d.Volume]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -704,3 +663,54 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c0356d0ba92a1b88dbec557c9706dec10d39b53bd74af24510f519ceae784aea(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    email: builtins.str,
+    hosted_zone_domain: builtins.str,
+    aws_cli_docker_tag: typing.Optional[builtins.str] = None,
+    certbot_docker_tag: typing.Optional[builtins.str] = None,
+    certbot_schedule_interval: typing.Optional[jsii.Number] = None,
+    container_insights: typing.Optional[builtins.bool] = None,
+    host_instance_spot_price: typing.Optional[builtins.str] = None,
+    host_instance_type: typing.Optional[builtins.str] = None,
+    log_group: typing.Optional[_aws_cdk_aws_logs_ceddda9d.ILogGroup] = None,
+    record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+    server_task_definition: typing.Optional[typing.Union[LowCostECSTaskDefinitionOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8a4e374b4001b2d1a00530b347f4892645cdf6f0c73a3b5609e0b85fb859de79(
+    *,
+    email: builtins.str,
+    hosted_zone_domain: builtins.str,
+    aws_cli_docker_tag: typing.Optional[builtins.str] = None,
+    certbot_docker_tag: typing.Optional[builtins.str] = None,
+    certbot_schedule_interval: typing.Optional[jsii.Number] = None,
+    container_insights: typing.Optional[builtins.bool] = None,
+    host_instance_spot_price: typing.Optional[builtins.str] = None,
+    host_instance_type: typing.Optional[builtins.str] = None,
+    log_group: typing.Optional[_aws_cdk_aws_logs_ceddda9d.ILogGroup] = None,
+    record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+    server_task_definition: typing.Optional[typing.Union[LowCostECSTaskDefinitionOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__002ebbd53d2519dadc4020acc93b39be5a360ef0d6f0ca12153b8e9f6ca81d6e(
+    *,
+    containers: typing.Sequence[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinitionOptions, typing.Dict[builtins.str, typing.Any]]],
+    task_definition: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.Ec2TaskDefinitionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    volumes: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_ecs_ceddda9d.Volume, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
